@@ -19,7 +19,6 @@
 
 package org.apache.cxf.configuration.jsse;
 
-import java.io.ByteArrayInputStream;
 import java.io.File;
 import java.io.IOException;
 import java.io.InputStream;
@@ -171,13 +170,13 @@ public final class SSLUtils {
 
     public static KeyManager[] loadKeyStore(KeyManagerFactory kmf,
                                                KeyStore ks,
-                                               ByteArrayInputStream bin,
+                                               InputStream is,
                                                String keyStoreLocation,
                                                String keyStorePassword,
                                                Logger log) {
         KeyManager[] keystoreManagers = null;
         try {
-            ks.load(bin, keyStorePassword.toCharArray());
+            ks.load(is, keyStorePassword.toCharArray());
             kmf.init(ks, keyStorePassword.toCharArray());
             keystoreManagers = kmf.getKeyManagers();
             LogUtils.log(log,
@@ -433,7 +432,7 @@ public final class SSLUtils {
 
     private static String[] getSystemCiphersuites(Logger log) {
         String jvmCipherSuites = System.getProperty(HTTPS_CIPHER_SUITES);
-        if ((jvmCipherSuites != null) && (!jvmCipherSuites.isEmpty())) {
+        if ((jvmCipherSuites != null) && !jvmCipherSuites.isEmpty()) {
             LogUtils.log(log, Level.FINE, "CIPHERSUITES_SYSTEM_PROPERTY_SET", jvmCipherSuites);
             return jvmCipherSuites.split(",");
         }
