@@ -23,30 +23,24 @@ import java.io.Closeable;
 import java.io.IOException;
 import java.io.UncheckedIOException;
 import java.io.Writer;
-import java.lang.invoke.MethodHandle;
-import java.lang.invoke.MethodHandles;
-import java.lang.invoke.MethodHandles.Lookup;
-import java.lang.invoke.MethodType;
-import java.lang.reflect.Constructor;
 import java.lang.reflect.Method;
 import java.net.URL;
 import java.util.ArrayList;
 import java.util.Collection;
-import java.util.EventListener;
 import java.util.List;
 import java.util.concurrent.CopyOnWriteArrayList;
 import java.util.logging.Level;
 import java.util.logging.Logger;
 
-import javax.annotation.PostConstruct;
 import javax.net.ssl.KeyManager;
 import javax.net.ssl.SSLContext;
-import javax.servlet.RequestDispatcher;
-import javax.servlet.ServletContext;
-import javax.servlet.ServletException;
-import javax.servlet.http.HttpServletRequest;
-import javax.servlet.http.HttpServletResponse;
 
+import jakarta.annotation.PostConstruct;
+import jakarta.servlet.RequestDispatcher;
+import jakarta.servlet.ServletContext;
+import jakarta.servlet.ServletException;
+import jakarta.servlet.http.HttpServletRequest;
+import jakarta.servlet.http.HttpServletResponse;
 import org.apache.cxf.Bus;
 import org.apache.cxf.common.i18n.Message;
 import org.apache.cxf.common.logging.LogUtils;
@@ -62,9 +56,13 @@ import org.apache.cxf.interceptor.Fault;
 import org.apache.cxf.transport.HttpUriMapper;
 import org.apache.cxf.transport.http.HttpServerEngineSupport;
 import org.eclipse.jetty.alpn.server.ALPNServerConnectionFactory;
+import org.eclipse.jetty.http.BadMessageException;
+import org.eclipse.jetty.http.HttpFields.Mutable;
 import org.eclipse.jetty.http.HttpStatus;
 import org.eclipse.jetty.http2.server.HTTP2CServerConnectionFactory;
 import org.eclipse.jetty.http2.server.HTTP2ServerConnectionFactory;
+import org.eclipse.jetty.io.Connection;
+import org.eclipse.jetty.io.EndPoint;
 import org.eclipse.jetty.security.SecurityHandler;
 import org.eclipse.jetty.server.AbstractConnector;
 import org.eclipse.jetty.server.ConnectionFactory;
@@ -613,30 +611,14 @@ public class JettyHTTPServerEngine implements ServerEngine, HttpServerEngineSupp
 
         try {
             Container container = getContainer(server);
-            // Attempt to support Jetty 9.x (Apache Karaf) and Jetty 10.x variations:
-            //    boolean addEventListener(EventListener listener);
-            //    void addEventListener(Container.Listener listener);
-            findAddEventListener(container).invoke(mBeanContainer);
+            container.addEventListener(mBeanContainer);
             mBeanContainer.beanAdded(null, server);
         } catch (RuntimeException rex) {
             throw rex;
-        } catch (Throwable r) {
+        } catch (Exception r) {
             throw new RuntimeException(r);
         }
     }
-
-    private MethodHandle findAddEventListener(Container container) 
-            throws NoSuchMethodException, IllegalAccessException {
-        final Lookup lookup = MethodHandles.publicLookup();
-        try {
-            return lookup.findVirtual(container.getClass(), "addEventListener", 
-                MethodType.methodType(boolean.class, EventListener.class)).bindTo(container);
-        } catch (final IllegalAccessException | NoSuchMethodException ex) {
-            return lookup.findVirtual(container.getClass(), "addEventListener", 
-                MethodType.methodType(void.class, Container.Listener.class)).bindTo(container);
-        }
-    }
-
     private void removeServerMBean() {
         try {
             mBeanContainer.beanRemoved(null, server);
@@ -713,18 +695,9 @@ public class JettyHTTPServerEngine implements ServerEngine, HttpServerEngineSupp
                         // additional dependency.
                         final ALPNServerConnectionFactory alpn = new ALPNServerConnectionFactory();
                         alpn.setDefaultProtocol(httpFactory.getProtocol());
-                                                
-                        Constructor<SslConnectionFactory>[] cons 
-                            = ReflectionUtil.getDeclaredConstructors(SslConnectionFactory.class);
-                        for (Constructor<SslConnectionFactory> c : cons) {
-                            if (c.getParameterCount() == 2 
-                                && c.getParameterTypes()[1] == String.class
-                                && c.getParameterTypes()[0].isInstance(sslcf)) {
-                                SslConnectionFactory scf = c.newInstance(sslcf, alpn.getProtocol());
-                                connectionFactories.add(scf);
-                            }
-                        }
                         
+                        final SslConnectionFactory scf = new SslConnectionFactory(sslcf, alpn.getProtocol());
+                        connectionFactories.add(scf);
                         connectionFactories.add(alpn);
                         connectionFactories.add(new HTTP2ServerConnectionFactory(httpConfig));
                     } catch (Throwable ex) {
@@ -733,17 +706,10 @@ public class JettyHTTPServerEngine implements ServerEngine, HttpServerEngineSupp
                         }
                     }
                 }
+                
                 if (connectionFactories.isEmpty()) {
-                    Constructor<SslConnectionFactory>[] cons 
-                        = ReflectionUtil.getDeclaredConstructors(SslConnectionFactory.class);
-                    for (Constructor<SslConnectionFactory> c : cons) {
-                        if (c.getParameterCount() == 2 
-                            && c.getParameterTypes()[1] == String.class
-                            && c.getParameterTypes()[0].isInstance(sslcf)) {
-                            SslConnectionFactory scf = c.newInstance(sslcf, httpFactory.getProtocol());
-                            connectionFactories.add(scf);
-                        }
-                    }
+                    final SslConnectionFactory scf = new SslConnectionFactory(sslcf, httpFactory.getProtocol());
+                    connectionFactories.add(scf);
                 }
                 
                 // Ensure http/1.1 is last in the list so it is the lowest priority in ALPN
@@ -757,13 +723,22 @@ public class JettyHTTPServerEngine implements ServerEngine, HttpServerEngineSupp
             } else if (isHttp2Enabled(bus)) {
                 connectionFactories.add(httpFactory);
                 try {
-                    connectionFactories.add(new NoUpgradeHTTP2CServerConnectionFactory(httpConfig));
+                    connectionFactories.add(new HTTP2CServerConnectionFactory(httpConfig) {
+
+                        @Override
+                        public Connection upgradeConnection(Connector c, EndPoint endPoint,
+                                                            org.eclipse.jetty.http.MetaData.Request request,
+                                                            Mutable response101)
+                            throws BadMessageException {
+                            if (request.getContentLength() > 0 
+                                || request.getFields().contains("Transfer-Encoding")) {
+                                // if there is a body, we cannot upgrade
+                                return null;
+                            }
+                            return super.upgradeConnection(c, endPoint, request, response101);
+                        }
+                    });
                 } catch (Throwable ex) {
-                    try {
-                        connectionFactories.add(new HTTP2CServerConnectionFactory(httpConfig));
-                    } catch (Throwable e2) {
-                        //ignore
-                    }
                     if (isHttp2Required(bus)) {
                         throw ex;
                     }
@@ -1133,7 +1108,7 @@ public class JettyHTTPServerEngine implements ServerEngine, HttpServerEngineSupp
                 if (mBeanContainer != null) {
                     removeServerMBean();
                 }
-                // After upgrade Jetty to 10.0.12, server.destroy() will clear all MBeans from container
+                // After upgrade Jetty to 11.0.8, server.destroy() will clear all MBeans from container
                 // The old version doesn't behave like this because MBeanContainer was shareable but
                 // is not anymore (the factory should create new a container for each server engine).
                 server.destroy();
